==> nerualpha-4.0.1-py3-none-any.whl: nerualpha/providers/voice/contracts/playStopPayload.py <==
from dataclasses import dataclass, field, asdict
from typing import Dict, List, Generic, TypeVar
from abc import ABC, abstractmethod

from nerualpha.providers.voice.contracts.IPlayStopPayload import IPlayStopPayload
from nerualpha.providers.voice.csEvents import CSEvents
from nerualpha.providers.voice.contracts.IPlayStopBody import IPlayStopBody
from nerualpha.providers.voice.contracts.playStopBody import PlayStopBody

@dataclass
class PlayStopPayload(IPlayStopPayload):
    body: IPlayStopBody
    type_: str
    to: str = None
    def __init__(self,playId,to = None):
        self.type_ = CSEvents.AudioPlayStop
        self.body = PlayStopBody(playId)
        if to is not None:
            self.to = to
        
    
    def reprJSON(self):
        result = {}
        dict = asdict(self)
        keywordsMap = {"from_":"from","del_":"del","import_":"import","type_":"type"}
        for key in dict:
            val = getattr(self, key)

            if val is not None:
                if type(val) is list:
                    parsedList = []
                    for i in val:
                        if hasattr(i,'reprJSON'):
                            parsedList.append(i.reprJSON())
                        else:
                            parsedList.append(i)
                    val = parsedList

                if hasattr(val,'reprJSON'):
                    val = val.reprJSON()
                if key in keywordsMap:
                    key = keywordsMap[key]
                result.__setitem__(key.replace('_hyphen_', '-'), val)
        return result

==> nerualpha-5.0.1-py3-none-any.whl: nerualpha/providers/voice/contracts/playStopPayload.py <==
from dataclasses import dataclass, field, asdict
from typing import Dict, List, Generic, TypeVar
from abc import ABC, abstractmethod

from nerualpha.providers.voice.contracts.IPlayStopPayload import IPlayStopPayload
from nerualpha.providers.voice.csEvents import CSEvents
from nerualpha.providers.voice.contracts.IPlayStopBody import IPlayStopBody
from nerualpha.providers.voice.contracts.playStopBody import PlayStopBody

@dataclass
class PlayStopPayload(IPlayStopPayload):
    body: IPlayStopBody
    type_: str
    to: str = None
    def __init__(self,playId: str,to: str = None):
        self.type_ = CSEvents.AudioPlayStop
        self.body = PlayStopBody(playId)
        if to is not None:
            self.to = to
        
    
    def reprJSON(self):
        result = {}
        dict = asdict(self)
        keywordsMap = {"from_":"from","del_":"del","import_":"import","type_":"type", "return_":"return"}
        for key in dict:
            val = getattr(self, key)

            if val is not None:
                if type(val) is list:
                    parsedList = []
                    for i in val:
                        if hasattr(i,'reprJSON'):
                            parsedList.append(i.reprJSON())
                        else:
                            parsedList.append(i)
                    val = parsedList

                if hasattr(val,'reprJSON'):
                    val = val.reprJSON()
                if key in keywordsMap:
                    key = keywordsMap[key]
                result.__setitem__(key.replace('_hyphen_', '-'), val)
        return result
